==> affycomp_1.16.0.zip: affycomp/doc/affycomp.R <==
###################################################
### chunk number 1: 
###################################################
library(affycomp)


###################################################
### chunk number 2: 
###################################################
data(mas5.assessment)
data(rma.assessment)


###################################################
### chunk number 3: 
###################################################
names(mas5.assessment)


###################################################
### chunk number 4: 
###################################################
affycompPlot(mas5.assessment$MA)


###################################################
### chunk number 5: 
###################################################
affycomp.figure2(mas5.assessment$Dilution)


###################################################
### chunk number 6: 
###################################################
affycomp.figure3(mas5.assessment$Dilution)


###################################################
### chunk number 7: 
###################################################
par(mfrow=c(2,1))
affycomp.figure4a(mas5.assessment$Signal)
affycomp.figure4b(mas5.assessment$Dilution)


###################################################
### chunk number 8: 
###################################################
par(mfrow=c(2,1))
affycomp.figure5a(mas5.assessment$FC)
affycomp.figure5b(mas5.assessment$FC)


###################################################
### chunk number 9: 
###################################################
par(mfrow=c(2,1))
affycomp.figure6a(mas5.assessment$FC)
affycomp.figure6b(mas5.assessment$FC)


###################################################
### chunk number 10: 
###################################################
par(mfrow=c(2,1))
affycompPlot(mas5.assessment$MA, rma.assessment$MA)


###################################################
### chunk number 11: 
###################################################
affycomp.compfig2(list(mas5.assessment$Dilution, rma.assessment$Dilution),
                  method.names=c("MAS 5.0","RMA"))


###################################################
### chunk number 12: 
###################################################
affycomp.compfig3(list(mas5.assessment$Dilution, rma.assessment$Dilution),
                  method.names=c("MAS 5.0","RMA"))


###################################################
### chunk number 13: 
###################################################
par(mfrow=c(2,1))
affycomp.compfig4a(list(mas5.assessment$Signal, rma.assessment$Signal),
                  method.names=c("MAS 5.0","RMA"))
affycomp.compfig4b(list(mas5.assessment$Dilution, rma.assessment$Dilution),
                  method.names=c("MAS 5.0","RMA"))


###################################################
### chunk number 14: 
###################################################
par(mfrow=c(2,1))
affycomp.compfig5a(list(mas5.assessment$FC, rma.assessment$FC),
                  method.names=c("MAS 5.0","RMA"))
affycomp.compfig5b(list(mas5.assessment$FC2, rma.assessment$FC2),
                  method.names=c("MAS 5.0","RMA"))


###################################################
### chunk number 15: 
###################################################
par(mfrow=c(2,2))
affycomp.figure6a(mas5.assessment$FC, main="a) MAS 5.0", ylim=c(-12,12))
affycomp.figure6a(rma.assessment$FC, main="a) RMA", ylim=c(-12,12))
affycomp.figure6b(mas5.assessment$FC, main="b) MAS 5.0", ylim=c(-6,6))
affycomp.figure6b(rma.assessment$FC, main="b) RMA", ylim=c(-6,6))


###################################################
### chunk number 16: 
###################################################
data(rma.assessment)
data(mas5.assessment)
tableAll(rma.assessment, mas5.assessment)


###################################################
### chunk number 17: 
###################################################
affycompTable(rma.assessment, mas5.assessment)


###################################################
### chunk number 18: 
###################################################
data(rma.sd.assessment)
data(lw.sd.assessment)
tableAll(rma.sd.assessment, lw.sd.assessment)


###################################################
### chunk number 19: 
###################################################
affycompPlot(lw.sd.assessment, rma.sd.assessment)


###################################################
### chunk number 20: 
###################################################
affycompPlot(lw.sd.assessment)

==> affycomp_1.26.0.zip: affycomp/doc/affycomp.R <==
###################################################
### chunk number 1: 
###################################################
#line 30 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
library(affycomp)


###################################################
### chunk number 2: 
###################################################
#line 105 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
data(mas5.assessment)
data(rma.assessment)


###################################################
### chunk number 3: 
###################################################
#line 114 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
names(mas5.assessment)


###################################################
### chunk number 4: 
###################################################
#line 141 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
affycompPlot(mas5.assessment$MA)


###################################################
### chunk number 5: 
###################################################
#line 160 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
affycomp.figure2(mas5.assessment$Dilution)


###################################################
### chunk number 6: 
###################################################
#line 174 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
affycomp.figure3(mas5.assessment$Dilution)


###################################################
### chunk number 7: 
###################################################
#line 189 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
par(mfrow=c(2,1))
affycomp.figure4a(mas5.assessment$Signal)
affycomp.figure4b(mas5.assessment$Dilution)


###################################################
### chunk number 8: 
###################################################
#line 205 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
par(mfrow=c(2,1))
affycomp.figure5a(mas5.assessment$FC)
affycomp.figure5b(mas5.assessment$FC)


###################################################
### chunk number 9: 
###################################################
#line 222 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
par(mfrow=c(2,1))
affycomp.figure6a(mas5.assessment$FC)
affycomp.figure6b(mas5.assessment$FC)


###################################################
### chunk number 10: 
###################################################
#line 243 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
par(mfrow=c(2,1))
affycompPlot(mas5.assessment$MA, rma.assessment$MA)


###################################################
### chunk number 11: 
###################################################
#line 263 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
affycomp.compfig2(list(mas5.assessment$Dilution, rma.assessment$Dilution),
                  method.names=c("MAS 5.0","RMA"))


###################################################
### chunk number 12: 
###################################################
#line 277 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
affycomp.compfig3(list(mas5.assessment$Dilution, rma.assessment$Dilution),
                  method.names=c("MAS 5.0","RMA"))


###################################################
### chunk number 13: 
###################################################
#line 293 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
par(mfrow=c(2,1))
affycomp.compfig4a(list(mas5.assessment$Signal, rma.assessment$Signal),
                  method.names=c("MAS 5.0","RMA"))
affycomp.compfig4b(list(mas5.assessment$Dilution, rma.assessment$Dilution),
                  method.names=c("MAS 5.0","RMA"))


###################################################
### chunk number 14: 
###################################################
#line 311 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
par(mfrow=c(2,1))
affycomp.compfig5a(list(mas5.assessment$FC, rma.assessment$FC),
                  method.names=c("MAS 5.0","RMA"))
affycomp.compfig5b(list(mas5.assessment$FC2, rma.assessment$FC2),
                  method.names=c("MAS 5.0","RMA"))


###################################################
### chunk number 15: 
###################################################
#line 330 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
par(mfrow=c(2,2))
affycomp.figure6a(mas5.assessment$FC, main="a) MAS 5.0", ylim=c(-12,12))
affycomp.figure6a(rma.assessment$FC, main="a) RMA", ylim=c(-12,12))
affycomp.figure6b(mas5.assessment$FC, main="b) MAS 5.0", ylim=c(-6,6))
affycomp.figure6b(rma.assessment$FC, main="b) RMA", ylim=c(-6,6))


###################################################
### chunk number 16: 
###################################################
#line 352 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
data(rma.assessment)
data(mas5.assessment)
tableAll(rma.assessment, mas5.assessment)


###################################################
### chunk number 17: 
###################################################
#line 361 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
affycompTable(rma.assessment, mas5.assessment)


###################################################
### chunk number 18: 
###################################################
#line 371 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
data(rma.sd.assessment)
data(lw.sd.assessment)
tableAll(rma.sd.assessment, lw.sd.assessment)


###################################################
### chunk number 19: 
###################################################
#line 382 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
affycompPlot(lw.sd.assessment, rma.sd.assessment)


###################################################
### chunk number 20: 
###################################################
#line 397 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2rM4EG/R.INSTALLfa428e/affycomp/inst/doc/affycomp.Rnw"
affycompPlot(lw.sd.assessment)
